IoReadError

Enum IoReadError 

pub enum IoReadError {
    ImmediateFin,
    UnexpectedFin,
    Reset,
    NotConnected,
}
Available on crate feature async only.
Error during read operations.

Variants



ImmediateFin

Read failed because immediate EOF (attempt reading the first byte).

In this case, zero bytes have been read during the operation.



UnexpectedFin

Read failed because EOF reached in the middle of operation.

In this case, at least one byte has been read during the operation.



Reset

Read failed because peer interrupted operation (at any point).

In this case, zero or more bytes might be have read during the operation.



NotConnected

Read failed because peer not is not connected, or disconnected (at any point).

In this case, zero or more bytes might be have read during the operation.