IoWriteError

Enum IoWriteError 

pub enum IoWriteError {
    Stopped,
    NotConnected,
}
Available on crate feature async only.
Error during write operation.

Variants



Stopped

Write failed because peer stopped operation.

In this case, zero or more bytes might be have written during the operation.



NotConnected

Write failed because peer not is not connected.

In this case, zero or more bytes might be have written during the operation.